package com.yiqi.system.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.system.domain.SysMessageConfig;

/**
 * 消息配置Service接口
 *
 * @author douya
 * @date 2024-11-22
 */
public interface ISysMessageConfigService extends IService<SysMessageConfig> {

    /**
     * 查询消息配置
     *
     * @param id 消息配置主键
     * @return 消息配置
     */
    public SysMessageConfig selectSysMessageConfigById(Long id);

    /**
     * 查询消息配置列表
     *
     * @param sysMessageConfig 消息配置
     * @return 消息配置集合
     */
    public List<SysMessageConfig> selectSysMessageConfigList(SysMessageConfig sysMessageConfig);

    /**
     * 新增消息配置
     *
     * @param sysMessageConfig 消息配置
     * @return 结果
     */
    public int insertSysMessageConfig(SysMessageConfig sysMessageConfig);

    /**
     * 修改消息配置
     *
     * @param sysMessageConfig 消息配置
     * @return 结果
     */
    public int updateSysMessageConfig(SysMessageConfig sysMessageConfig);

    /**
     * 批量删除消息配置
     *
     * @param ids 需要删除的消息配置主键集合
     * @return 结果
     */
    public int deleteSysMessageConfigByIds(Long[] ids);

    /**
     * 删除消息配置信息
     *
     * @param id 消息配置主键
     * @return 结果
     */
    public int deleteSysMessageConfigById(Long id);


    /**
     * 修改消息配置状态
     *
     * @param sysMessageConfig 消息配置
     * @return 结果
     */
    public int updateSysMessageConfigStatus(SysMessageConfig sysMessageConfig);

    /**
     * 根据code查询消息配置
     *
     * @param code
     * @return
     */
    public SysMessageConfig selectSysMessageConfigByCode(String code);
}
